@@ -13,7 +13,7 @@ import functools
 from collections import defaultdict
 
 
-__version__ = '1.20.0'
+__version__ = '1.20.1'
 _PARAMS = re.compile(r'{\w+}')
 
 # Implementation note:  This file is intended to be a standalone file
@@ -494,12 +494,17 @@ class Response(object):
         body = response_dict['body']
 
         if _matches_content_type(content_type, binary_types):
-            if _matches_content_type(content_type, ['application/json']):
+            if _matches_content_type(content_type, ['application/json']) or \
+                    not content_type:
                 # There's a special case when a user configures
                 # ``application/json`` as a binary type.  The default
                 # json serialization results in a string type, but for binary
                 # content types we need a type bytes().  So we need to special
                 # case this scenario and encode the JSON body to bytes().
+                #
+                # If a user does not provide a content type header, which can
+                # happen if they return a python type instead of a ``Response``
+                # type, then we assume the content is application/json.
                 body = body if isinstance(body, bytes) \
                     else body.encode('utf-8')
             body = self._base64encode(body)
@@ -1776,6 +1781,7 @@ class Blueprint(DecoratorAPI):
         # Blueprint.register() and provide an app object.  Once
         # we have access to an app, we can call the actual _wrap_handler
         # which will have access to middleware.
+        @functools.wraps(user_handler)
         def _defer_wrap_handler(app):
             # pylint: disable=protected-access
             return app._wrap_handler(handler_type, handler_name,
